package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.digests.MD5Digest;
import cn.com.infosec.crypto.digests.SHA1Digest;
import cn.com.infosec.crypto.digests.SHA224Digest;
import cn.com.infosec.crypto.digests.SHA256Digest;
import cn.com.infosec.crypto.digests.SHA384Digest;
import cn.com.infosec.crypto.digests.SHA512Digest;
import cn.com.infosec.util.Strings;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

class JCEDigestUtil {
   private static Set md5 = new HashSet();
   private static Set sha1 = new HashSet();
   private static Set sha224 = new HashSet();
   private static Set sha256 = new HashSet();
   private static Set sha384 = new HashSet();
   private static Set sha512 = new HashSet();
   private static Map oids = new HashMap();

   static {
      md5.add("MD5");
      DERObjectIdentifier var0;
      md5.add((var0 = PKCSObjectIdentifiers.md5).getId());
      sha1.add("SHA1");
      sha1.add("SHA-1");
      DERObjectIdentifier var1;
      sha1.add((var1 = OIWObjectIdentifiers.idSHA1).getId());
      sha224.add("SHA224");
      sha224.add("SHA-224");
      DERObjectIdentifier var2;
      sha224.add((var2 = NISTObjectIdentifiers.id_sha224).getId());
      sha256.add("SHA256");
      sha256.add("SHA-256");
      DERObjectIdentifier var3;
      sha256.add((var3 = NISTObjectIdentifiers.id_sha256).getId());
      sha384.add("SHA384");
      sha384.add("SHA-384");
      DERObjectIdentifier var4;
      sha384.add((var4 = NISTObjectIdentifiers.id_sha384).getId());
      sha512.add("SHA512");
      sha512.add("SHA-512");
      DERObjectIdentifier var5;
      sha512.add((var5 = NISTObjectIdentifiers.id_sha512).getId());
      oids.put("MD5", var0);
      oids.put(var0.getId(), var0);
      oids.put("SHA1", var1);
      oids.put("SHA-1", var1);
      oids.put(var1.getId(), var1);
      oids.put("SHA224", var2);
      oids.put("SHA-224", var2);
      oids.put(var2.getId(), var2);
      oids.put("SHA256", var3);
      oids.put("SHA-256", var3);
      oids.put(var3.getId(), var3);
      oids.put("SHA384", var4);
      oids.put("SHA-384", var4);
      oids.put(var4.getId(), var4);
      oids.put("SHA512", var5);
      oids.put("SHA-512", var5);
      oids.put(var5.getId(), var5);
   }

   static Digest getDigest(String digestName) {
      digestName = Strings.toUpperCase(digestName);
      if (sha1.contains(digestName)) {
         return new SHA1Digest();
      } else if (md5.contains(digestName)) {
         return new MD5Digest();
      } else if (sha224.contains(digestName)) {
         return new SHA224Digest();
      } else if (sha256.contains(digestName)) {
         return new SHA256Digest();
      } else if (sha384.contains(digestName)) {
         return new SHA384Digest();
      } else {
         return sha512.contains(digestName) ? new SHA512Digest() : null;
      }
   }

   static boolean isSameDigest(String digest1, String digest2) {
      return sha1.contains(digest1) && sha1.contains(digest2) || sha224.contains(digest1) && sha224.contains(digest2) || sha256.contains(digest1) && sha256.contains(digest2) || sha384.contains(digest1) && sha384.contains(digest2) || sha512.contains(digest1) && sha512.contains(digest2) || md5.contains(digest1) && md5.contains(digest2);
   }

   static DERObjectIdentifier getOID(String digestName) {
      return (DERObjectIdentifier)oids.get(digestName);
   }
}
